@@ -13,6 +13,8 @@
  * Usage
  * [bando@bando cdic-1.0]$ ./cdic [word] or [text]
  * 
+ * $Id: cdic.c,v 1.5 2008/01/11 13:33:04 bando Exp $
+ * 
  */
 
 #include <stdio.h>
@@ -94,24 +96,6 @@ typedef struct _config {
 typedef void (*dic_func)(char *str, config *cf);
 typedef void (*trans_func)(char *str, config *cf);
 
-/*
-enum _dic_type { NAVER, YAHOO, DAUM, EMPAS };
-enum _trans_type { GOOGLE_TRANS, YAHOO_TRANS };
-enum _ANSI { GRAY = 30, RED, GREEN, YELLOW, BLUE, MAGENTA, CYAN, WHITE, NOT = 00, BOLD = 1, UNBOLD = 0 };
-
-#ifdef HAVE_ICONV
-enum _iconv_err_type {
-	ICONV_ERR_SUCCESS = SUCCESS,
-	ICONV_ERR_CONVERTER,
-	ICONV_ERR_WRONG_CHARSET,
-	ICONV_ERR_TOO_BIG,
-	ICONV_ERR_ILLEGAL_SEQ,
-	ICONV_ERR_ILLEGAL_CHAR,
-	ICONV_ERR_UNKNOWN
-};
-#endif
-*/
-
 typedef struct _dic_cmd {
 	char *type_name;
 	dic_type type;
@@ -131,17 +115,6 @@ typedef struct _http_request {
 	unsigned int port;
 } http_request;
 
-
-/*
-typedef struct _config {
-	dic_type dic;
-	trans_type trans;
-#ifdef HAVE_ICONV
-	char charset[64];
-#endif
-} config;
-*/
-
 int socket_get_option (int sock, int level, int optname, void *optval);
 int socket_set_option (int sock, int level, int optname, const void *optval);
 int socket_set_blocking (int sock, int block);
@@ -219,7 +192,6 @@ int main (int argc, char **argv)
 			trans[cf.trans].func(argv[1], &cf);
 		} else if (strchr(argv[1], '=')) {
 			if (config_reload (argv[1], &cf) == SUCCESS) {
-				//printf(" ˻   => %s : ", strchr(argv[1], '=') + 1);
 				result = (config_create (buf, &cf) == SUCCESS) ? ansi_color("", GREEN, UNBOLD) : ansi_color("", RED, UNBOLD);
 				printf("  [%s]\n", result);
 				if (result) free(result);
@@ -1255,7 +1227,7 @@ void trans_google (char *str, config *cf)
 			recved = out_str;
 		}
 #endif
-		str_cut(recved, "<textarea name=utrans wrap=SOFT dir=ltr rows=5 id=suggestion>", "</textarea>");
+		str_cut(recved, "<textarea name=utrans wrap=SOFT dir=\"ltr\" rows=5 id=suggestion>", "</textarea>");
 		printf("%s\n", recved);
 		free(recved);
 	}
